@@ -1,4 +1,4 @@
 import RainbowMonitoringSDK.exporters
-import RainbowMonitoringSDK.probes
+import RainbowMonitoringSDK.probes as probes
 import RainbowMonitoringSDK.utils
 from .controller import Controller
